[![Build Status](https://travis-ci.org/edielsonpf/wsn-toolkit.svg?branch=main)](https://travis-ci.org/edielsonpf/wsn-toolkit)
[![DOI](https://zenodo.org/badge/319434165.svg)](https://zenodo.org/badge/latestdoi/319434165)

**wsn-toolkit** is a Python module for simulation of Wireless Sensor Networks

Source code
~~~~~~~~~~~

You can check the latest sources with the command:

    git clone https://github.com/edielsonpf/wsn-toolkit.git


    
